@@ -45,8 +45,8 @@ class AddCommand(OvirtCommand):
 
         - This help will list all available attribute options for given subresource creation
           
-          * format      - help add subresource_name --resource-identifier xxx
-          * example     - help add disk --vm-identifier myvm
+          * format      - help add subresource_name --parent-resource-identifier xxx
+          * example     - help add disk --parent-vm-identifier myvm
 
         == Available Types ==
 
@@ -56,10 +56,15 @@ class AddCommand(OvirtCommand):
 
         == Base Identifiers ==
 
-        Some objects can only be created inside other objects. For example a
-        disk can only be created inside a virtual machine. In this case, one
-        or more base identifier options need to be given to identify the
-        containing object. These options have the form --<type>id <id>.
+        Some objects can exist inside other objects. For example, a disk can
+        exist in the content of a virtual machine. In this case, one or more
+        object identifier options need to be provided to identify the
+        containing object.
+
+        An object identifier is an option of the form
+        '--parent-<type>-identifier <id>' or '--parent-<type>-name <name>'. This
+        would identify an object with type <type> and id <id> or name <name>.
+        See the examples section below for a few examples.
 
         == Attribute Options ==
 
@@ -86,7 +91,7 @@ class AddCommand(OvirtCommand):
                       
         - This example create vm nic:
 
-          $ add nic --vm-identifier cli_vm3 --network-name engine --name test
+          $ add nic --parent-vm-name cli_vm3 --network-name engine --name test
 
 
         == Return Values ==
