@@ -1,11 +1,11 @@
 
-import sys
+import os
 
-if sys.platform in ('linux2',):
+if os.name == "posix":
     from ovirtcli.platform.posix import util
     from ovirtcli.platform.posix import vnc
     from ovirtcli.platform.posix import spice
     from ovirtcli.platform.posix import ssh
 
-elif sys.platform in ('win32',):
+else:
     pass
