@@ -25,8 +25,8 @@ class CapabilitiesCmdShell(CmdShell):
        'features'
     ]
 
-    def __init__(self, context, parser):
-        CmdShell.__init__(self, context, parser)
+    def __init__(self, context):
+        CmdShell.__init__(self, context)
 
     def do_capabilities(self, args):
         return self.context.execute_string(CapabilitiesCmdShell.NAME + ' ' + args + '\n')
